@@ -4,12 +4,13 @@ use warnings;
 
 use Getopt::Std;
 my %opts;
-getopts('i:I:p:d:', \%opts);
+getopts('i:I:p:d:v', \%opts);
 
-die "Usage: send-syn.pl -i dstIp -p dstPort [ -I srcIp ] [ -d device ]\n"
+die "Usage: send-syn.pl -i dstIp -p dstPort [ -I srcIp ] [ -d device ] ".
+    "[ -v ]\n"
    unless $opts{i} && $opts{p};
 
-$Net::Pkt::Debug = 3;
+$Net::Pkt::Debug = 3 if $opts{v};
 
 # Overwrite autochosen one
 $Net::Pkt::Dev = $opts{d};
@@ -29,20 +30,19 @@ use Net::Pkt::Dump;
 my $dump = Net::Pkt::Dump->new(
    filter             => $frame->getFilter,
    unlinkAfterAnalyze => 1,
+   callStart          => 1,
 );
 
-$dump->start;
-
 print "Request:\n";
 $frame->ipPrint;
 $frame->tcpPrint;
 $frame->send;
 
-$dump->stop;
-
-$dump->analyze;
-if (my $reply = $frame->recv) {
-   print "\nReply:\n";
-   $reply->ipPrint;
-   $reply->tcpPrint;
+until ($Net::Pkt::Timeout) {
+   if ($dump->next && $frame->recv) {
+      print "\nReply:\n";
+      $frame->reply->ipPrint;
+      $frame->reply->tcpPrint;
+      last;
+   }
 }
